function plotter(results_table)
% PLOTTER Generates histogam, scatter and box plots from the results_table data.
%
% This function creates and saves several plots based on the data provided
% in the results_table. The plots include a combined scatter plot, box plots
% for Length and Connection Costs, and histograms for different constraints.
%
% INPUT:
%   results_table - A table containing the following columns:
%       Length - A column vector of lengths.
%       Connection_costs - A column vector of connection costs.
%       distribution - A cell array of labels for the distribution type.
%
% OUTPUT:
%   The function saves the generated plots as PNG and EPS files in a
%   timestamped folder within the "results" directory.
%
% USAGE:
%   plotter(results_table)
%
% EXAMPLE:
%   % Assuming results_table is already loaded in the workspace
%   plotter(results_table)



%% import of data in the case 
Length = results_table.Length;
% input_l= all_distributions.L_me;
Con_cost = results_table.Connection_costs;
distribution = results_table.distribution;
incre_len = results_table.Incre_dif_len;
incre_con = results_table.Incre_dif_con;
current_folder = string(datestr(datetime('now'),'dd_mm_yyyy hh_MM_ss'));
mkdir("results" + filesep + current_folder);
folder_layout = "results" + filesep + current_folder;

%% combined scatter plot

% Define colors and symbols for each group
% colors = [0 0.4470 0.7410; 1 0.5 0; 0.4660 0.6740 0.1880; [0, 0.5, 0.5]];

% % Blue, Orange, Green, Tyle
symbols = 'ods*'; % Circle, Square, Diamond, Upward-pointing triangle

colors = [0 0.4470 0.7410; 1 0.5 0; 0.4660 0.6740 0.1880]; % Blue, Orange, Green, Purple
% symbols = 'ods'; % Circle, Square, Diamond, Upward-pointing triangle
h = gscatter(Length,Con_cost,distribution,colors,symbols,7,'on')
legend('Location','southeast')
%jgroup = h(3)
% Set limits on the x-axis and y-axis

xlabel('Length [m]','Interpreter','latex')
ylabel('Connection Costs','Interpreter','latex')
full_file = fullfile(folder_layout,"combined_scatter.png");
full_file_1 = fullfile(folder_layout,"combined_scatter.eps");
exportgraphics(gcf, full_file);
exportgraphics(gcf,full_file_1,'ContentType','vector','Resolution',600 );

%% box plot for Length
% works correctly for distribution plotting
close all

t = tiledlayout(2,1,'TileSpacing','loose');
nexttile
boxplot(Length,distribution)
%xlabel('Boundary Conditions','Interpreter','latex')
ylabel('Length [m]','Interpreter','latex','Fontsize',12)
xlabel(t,'Selected distributions','Interpreter','latex','FontSize',12)

nexttile
boxplot(Con_cost,distribution)
%xlabel('Selected distribution','Interpreter','latex')
ylabel('Connection Costs','Interpreter','latex','FontSize',12)
% exportgraphics(gcf, folder_layout+'con_box_plot.png');
% exportgraphics(gcf,folder_layout+'con_box_plot.eps','ContentType','vector','Resolution',600);

% box plot for Connection costs
full_file = fullfile(folder_layout,"length_box_plot.png");
full_file_1 = fullfile(folder_layout,"length_box_plot.eps");
exportgraphics(gcf, full_file);
exportgraphics(gcf,full_file_1,'ContentType','vector','Resolution',600 );


%% comparative histogram for different distributions
close all
% pdf_func = @(x) (lambda^K/factorial(K-1)) * x.^(K-1) .* exp(-lambda*x);
% custom_k = makedist('custom_k', pdf_func)
% data = [1.2, 2.5, 3.1, 4.2, 5.5, 6.8];  % Your data
% %params = fitdist(fval(:,2, dist);close all

% Define color vectors
colors = [0 0.4470 0.7410; 1 0.5 0; 0.4660 0.6740 0.1880; 0 0.5 0.5];

% Create a tiled layout with 2 rows and 1 column
t = tiledlayout(2, 1, 'TileSpacing', 'loose');

% First histogram
nexttile
hc_1 = histogram(Con_cost(1:500), 'FaceColor', colors(1,:), 'EdgeColor', 'k', 'FaceAlpha', 0.8); % weibull
hold on
hc_2 = histogram(Con_cost(501:1000), 'FaceColor', colors(2,:), 'EdgeColor', 'k', 'FaceAlpha', 0.8); % uniform
hc_3 = histogram(Con_cost(1001:1500), 'FaceColor', colors(3,:), 'EdgeColor', 'k', 'FaceAlpha', 0.8); % uniform
hc_4 = histogram(Con_cost(1501:2000), 'FaceColor', colors(4,:), 'EdgeColor', 'k', 'FaceAlpha', 0.7); % beta
legend(distribution{1}, distribution{501}, distribution{1001}, distribution{1501}, 'Location', 'best')

hc_1.Normalization = 'probability';
hc_1.BinWidth = 0.25;
hc_2.Normalization = 'probability';
hc_2.BinWidth = 0.25;
hc_3.Normalization = 'probability';
hc_3.BinWidth = 0.25;
hc_4.Normalization = 'probability';
hc_4.BinWidth = 0.25;
xlabel('Connection costs', 'Interpreter', 'latex');

% Second histogram
nexttile
h_1 = histogram(Length(1:500), 'FaceColor', colors(1,:), 'EdgeColor', 'k', 'FaceAlpha', 0.8); % weibull
hold on
h_2 = histogram(Length(501:1000), 'FaceColor', colors(2,:), 'EdgeColor', 'k', 'FaceAlpha', 0.8); % normal
h_3 = histogram(Length(1001:1500), 'FaceColor', colors(3,:), 'EdgeColor', 'k', 'FaceAlpha', 0.8); % uniform
h_4 = histogram(Length(1501:2000), 'FaceColor', colors(4,:), 'EdgeColor', 'k', 'FaceAlpha', 0.7); % beta
legend(distribution{1}, distribution{501}, distribution{1001}, distribution{1501}, 'Location', 'best')

h_1.Normalization = 'probability';
h_1.BinWidth = 0.25;
h_2.Normalization = 'probability';
h_2.BinWidth = 0.25;
h_3.Normalization = 'probability';
h_3.BinWidth = 0.25;
h_4.Normalization = 'probability';
h_4.BinWidth = 0.25;
xlabel('Engine Room Length [m]', 'Interpreter', 'latex');

% Add a common ylabel for the entire tiled layout
ylabel(t, 'Probability Density Function [1/m]', 'Interpreter', 'latex');

% Export the figure

full_file = fullfile(folder_layout,"comb_histfit.png");
full_file_1 = fullfile(folder_layout,"comb_hist_fit.eps");
exportgraphics(gcf, full_file);
exportgraphics(gcf,full_file_1,'ContentType','vector','Resolution',600 );


%% Convergence plot of the experiment
%%% It could definitely be done also with a function

close all
fig1 = figure(1);

t1 = 1:500;
t2 = 460:500;
plot(t1,incre_len(t1),"Color",[0.4940 0.1840 0.5560])%special colour inclusion
hold on
plot(t1,incre_con(t1),"Color",[0.6350 0.0780 0.1840])

% Add an arrow pointing at the graph
annotation('arrow', [0.745, 0.84], [0.7, 0.14], 'Color', 'black');


legend('Length','Connection Cost')
% header = "Simulation Convergence";
% title(header,"Interpreter","None",'FontSize',15)
xlabel('Number of iterations','Interpreter','latex');
ylabel('Cumulative Incremental Difference','Interpreter','latex');
legend({'Length','Connection Cost'},'Location','northwest')
axes('Position',[.67 .7 .2 .2])
box on
plot(t2,incre_len(t2),"Color",[0.4940 0.1840 0.5560])
hold on
plot(t2,incre_con(t2),"Color",[0.6350 0.0780 0.1840])
xlabel('Number of iterations','Interpreter','latex');
ylabel('CID','Interpreter','latex');

full_file = fullfile(folder_layout,"_cum_dif_convergence.png");
full_file_1 = fullfile(folder_layout,"cum_dif_convergence.eps");
exportgraphics(gcf, full_file);
exportgraphics(gcf,full_file_1,'ContentType','vector','Resolution',600 );


end 