function plotter_3(results_table)
% PLOTTER_3 Generates histogam, scatter and box plots from the results_table data.
%
% This function creates and saves several plots based on the data provided
% in the results_table. The plots include a combined scatter plot, box plots
% for Length and Connection Costs, and histograms for different constraints.
%
% INPUT:
%   results_table - A table containing the following columns:
%       Length - A column vector of lengths.
%       Connection_costs - A column vector of connection costs.
%       distribution - A cell array of labels for the variable logical architectures.
%
% OUTPUT:
%   The function saves the generated plots as PNG and EPS files in a
%   timestamped folder within the "results" directory.
%
% USAGE:
%   plotter_3(results_table)
%
% EXAMPLE:
%   % Assuming results_table is already loaded in the workspace
%   plotter_3(results_table)




current_folder = string(datestr(datetime('now'),'dd_mm_yyyy hh_MM_ss'));
mkdir("results" + filesep + current_folder);
folder_layout = "results" + filesep + current_folder;
Length = results_table.Length;
Con_cost = results_table.Connection_costs;
distribution = results_table.distribution;
%% combined scatter plot
% Define colors and symbols for each group
% colors = [0 0.4470 0.7410; 1 0.5 0; 0.4660 0.6740 0.1880; [0, 0.5, 0.5]];

close all
colors = [
    0, 0, 0;   % Black
    0, 0, 1;   % Blue
    1, 0, 0    % Red
];
% % Blue, Orange, Green, Tyle
symbols = 'ods*'; % Circle, Square, Diamond, Upward-pointing triangle
h = gscatter(Length,Con_cost,distribution,colors,symbols,7,'on')
legend('Location','southeast')

xlabel('Length [m]','Interpreter','latex')
ylabel('Connection Costs','Interpreter','latex')
full_file = fullfile(folder_layout,"varlog_scatter.png");
full_file_1 = fullfile(folder_layout,"varlog_scatter.eps");
exportgraphics(gcf, full_file);
exportgraphics(gcf,full_file_1,'ContentType','vector','Resolution',600 );


%% box plot for Length
% works correctly for distribution plotting
close all

t = tiledlayout(2,1,'TileSpacing','loose')
nexttile
boxplot(Length,distribution)
%xlabel('Boundary Conditions','Interpreter','latex')
ylabel('Length [m]','Interpreter','latex','Fontsize',12)
xlabel(t,'Selected distributions','Interpreter','latex','FontSize',12)

nexttile
boxplot(Con_cost,distribution)
%xlabel('Selected distribution','Interpreter','latex')
ylabel('Connection Costs','Interpreter','latex','FontSize',12)

full_file = fullfile(folder_layout,"varlog_arch_box_plot.png");
full_file_1 = fullfile(folder_layout,"varlog_arch_box_plot.eps");
exportgraphics(gcf, full_file);
exportgraphics(gcf,full_file_1,'ContentType','vector','Resolution',600 );


%% Histogram with 6 combined figures

close all
fig5 = figure (5) % check the documentation for figures
%%%%% add legends and titles on the graphs
fval_normal = zeros(500,2);
fval_normal(:,1) = results_table.Connection_costs(501:1000);
fval_normal(:,2) = results_table.Length(501:1000);

fval_zero_con = zeros(500,2);
fval_zero_con(:,1) = results_table.Connection_costs(1:500);
fval_zero_con(:,2) = results_table.Length(1:500);


fval_full_con = zeros(500,2);
fval_full_con(:,1) = results_table.Connection_costs(1001:1500);
fval_full_con(:,2) = results_table.Length(1001:1500);

%h1 = histfit(fval(:,2))

t = tiledlayout(2,3,'TileSpacing','compact')


nexttile(2)
%yyaxis left
h = histogram(fval_normal(:,2),'Normalization','pdf') %Distribution of length
% h1 = histfit(fval(:,2))
m = mean(fval_normal(:,2));
s = std(fval_normal(:,2));


h.FaceColor = [0 0.5 0.5];
h.EdgeColor = 'r';
hold on

header = "Baseline Constraints";
xlabel('Engine room Length [m] ','interpreter','latex','FontSize',10);
 title(header,"Interpreter","latex",'FontSize',10) %alternatives could be latex, tex


nexttile(5)
h2 = histogram(fval_normal(:,1),'Normalization','pdf')
h2.FaceColor = [0 0.5 0.5];
h2.EdgeColor = 'r';
xlabel('Connection costs ','Interpreter','latex','FontSize',10);

nexttile(1)
m3 = mean(fval_zero_con(:,2));
s3 = std(fval_zero_con(:,2));

h3 = histogram(fval_zero_con(:,2),'Normalization','pdf')
h3.FaceColor = [0 0.5 0.5];
h3.EdgeColor = 'r';
header = "Zero Constraints ";
title(header,"Interpreter","latex",'FontSize',10) %alternatives could be latex, tex


nexttile(4)
h4 = histogram(fval_zero_con(:,1),'Normalization','pdf')
h4.FaceColor = [0 0.5 0.5];
h4.EdgeColor = 'r';


nexttile(3)
h5 = histogram(fval_full_con(:,2),'Normalization','pdf');
h5.FaceColor = [0 0.5 0.5];
h5.EdgeColor = 'r';

header = "Full Constraints";
 title(header,"Interpreter","latex",'FontSize',10) %alternatives could be latex, tex


nexttile(6)
h5 = histogram(fval_full_con(:,1),'Normalization','pdf')
h5.FaceColor = [0 0.5 0.5];
h5.EdgeColor = 'r';

ylabel(t,'Probablility Density Fuction','interpreter','latex','fontsize',10)
full_file = fullfile(folder_layout,"Histo6combo.png");
full_file_1 = fullfile(folder_layout,"Histo6combo.eps");
exportgraphics(gcf, full_file);
exportgraphics(gcf,full_file_1,'ContentType','vector','Resolution',600 );

end